@@ -26,6 +26,8 @@ from . mi_request import mi_request_programs
 
 from . mi_models import Endpoint
 
+from . mi_endpoints import mi_endpoint_get
+
 
 class MiApi:
     def __init__(self, host: str, port: int, usr: str, pwd: str):
@@ -79,3 +81,16 @@ class MiApi:
                 return record
         else:
             return None
+
+
+def get_api_for_endpoint(name: str) -> MiApi:
+    ''' Creates a MiApi object for a stored endpoint '''
+    endpoint = mi_endpoint_get(name)
+    return MiApi(
+        endpoint.host,
+        endpoint.port,
+        endpoint.usr,
+        endpoint.pwd
+        )
+
+
